---
title: llarp/dns/rr.hpp

---

# llarp/dns/rr.hpp



## Namespaces

| Name           |
| -------------- |
| **[llarp](Namespaces/namespacellarp.md)** <br>[crypto.hpp] |
| **[llarp::dns](Namespaces/namespacellarp_1_1dns.md)**  |

## Classes

|                | Name           |
| -------------- | -------------- |
| class | **[llarp::dns::RData](Classes/classllarp_1_1dns_1_1RData.md)**  |
| struct | **[llarp::dns::ResourceRecord](Classes/structllarp_1_1dns_1_1ResourceRecord.md)**  |




## Source code

```cpp
#pragma once

#include "llarp/util/status.hpp"
#include "llarp/util/str.hpp"
#include "llarp/util/types.hpp"
#include "name.hpp"
#include "serialize.hpp"
#include <cstdint>
#include <llarp/net/net_int.hpp>

#include <memory>
#include <optional>
#include <string>
#include <string_view>
#include <vector>

namespace llarp::dns
{

  enum class RRType : uint16_t
  {
    SRV = 33,
    AAAA = 28,
    TXT = 16,
    MX = 15,
    PTR = 12,
    CNAME = 5,
    NS = 2,
    A = 1
  };

  std::optional<RRType>
  get_rr_type(uint16_t i);

  std::string
  ToString(RRType t);

  class RData
  {
    bstring _raw;

   public:
    RData() = default;
    RData(const RData&) = default;
    RData(RData&&) = default;

    RData&
    operator=(const RData&) = default;
    RData&
    operator=(RData&&) = default;

    explicit RData(bstring_view& view);

    explicit RData(std::vector<std::string_view> dns_labels);
    explicit RData(net::ipv4addr_t ip);
    explicit RData(net::ipv6addr_t ip);

    explicit RData(uint16_t priority, std::vector<std::string_view> dns_labels);

    explicit RData(bstring&& raw);

    [[nodiscard]] constexpr const auto&
    data() const
    {
      return _raw;
    }

    std::vector<std::string_view>
    view_dns_labels() const;

    util::StatusObject
    to_json() const;

    std::string
    ToString() const;
  };

  struct ResourceRecord
  {
    ResourceRecord() = default;

    ResourceRecord(std::string name, RRType type, RData rdata, uint32_t ttl);

    explicit ResourceRecord(bstring_view& raw);

    bstring
    encode_dns() const;

    util::StatusObject
    to_json() const;

    std::string
    ToString() const;

    bool
    HasCNameForTLD(const std::string& tld) const;

    std::vector<std::string> rr_name_labels;
    RRType rr_type;
    uint32_t rr_ttl;
    RData rr_data;

   private:
    ResourceRecord(bstring&&);
  };

}  // namespace llarp::dns

template <>
constexpr inline bool llarp::IsToStringFormattable<llarp::dns::ResourceRecord> = true;

template <>
constexpr inline bool llarp::IsToStringFormattable<llarp::dns::RData> = true;

template <>
constexpr inline bool llarp::IsToStringFormattable<llarp::dns::RRType> = true;
```


-------------------------------

Updated on 2023-03-14 at 14:02:06 +0000
